Welcome to ``maskrcnn_utils`` Documentation
===========================================
``maskrcnn_utils`` is a repackage version of some utility functions implemented in maskrcnn-benchmark(FAIR). All the functions are written in CPLUS to get a better performance. We do some packaging work in order to easy reuse them in other circumstances.

Functions include:

- nms

Class:

- ROIAlign
- ROIPool

Installation
------------
.. code-block:: console

   $ pip install maskrcnn_utils

Quick Links
-----------
- `Github HomePage <https://github.com/iHateTa11B0y/CROIUtils>`_
- `maskrcnn-benckmark <https://github.com/facebookresearch/maskrcnn-benchmark/tree/master/maskrcnn_benchmark/csrc>`_
